function [v,probv,vdots,pdots,figure1] = createMBfig(molwt,Tvec,maxv,verts)
% Example: [v,probv,vdots,pdots,fig1] = createMBfig(20,100:50:300,1500,1);
% Jason Kahn U Maryland 2/25/2016  version 1.01
% All arguments are required. Plain argon at RT would be createMBfig(40,298,1000,0);
% Plots Maxwell-Boltzmann distributions for P(v) vs. v for a partcle 
% of mass molwt, at temperatures given in Tvec, up to maximum velocity maxv
% If verts = 1 plots vertical lines for most common, average, and rms
% velocities. Returns matrices of v's and P(v)'s, and the most common
% values, and figure handles (so calling functions can delete the plot)
% Jason Kahn, 11/10/09 - modified January 2016
mproton = 1.6726e-27;
mparticle = molwt*mproton;
kb = 1.381e-23;
v = 0:maxv/200:maxv ;
numv = size(v,2);
numT = size(Tvec,2);
probv(numv,numT) = 0;
vdots(numT,3) = 0;
pdots(numT,3) = 0;
legmat = cell(size(Tvec,2),1);
for i = 1:numT ;
    T = Tvec(i) ;
    probv(:,i) = 4*pi*(mparticle/(2*pi*kb*T))^1.5*v.^2.*...
        exp(-mparticle.*v.^2/(2*kb*T));
    legmat(i) = {[' T = ', num2str(T)]};
    vmode = sqrt(2*kb*T/mparticle) ;
    
% The "dots" matrices are (v,p) pairs for the mode, the average, and
% the rms velocities, the last being the v with the average kinetic
% energy. If you line up plots of p vs (.5mv^2) with different masses
% these dot points line up (at constant temperature) as they must. The
% normalization will be off because the differential energy is
% different for different masses.
% The Mbdist_vs_mass script does this for you.

    vdots(i,:) = vmode*[1 2/sqrt(pi) sqrt(3/2)] ;
    pdots(i,:) = 4*pi*(mparticle/(2*pi*kb*T))^1.5*vdots(i,:).^2.*...
        exp(-mparticle.*vdots(i,:).^2/(2*kb*T)) ;
end

scrsz = get(0,'ScreenSize');

% Create figure
figure1 = figure('Position',[100 scrsz(4)/2 scrsz(3)/2 scrsz(4)/2]);

% Create axes
axes1 = axes('Parent',figure1,'ZColor',[0 0.5 0],...
    'YColor',[0 0.5 0],...
    'XColor',[0 0.5 0],...
    'FontWeight','bold',...
    'FontSize',14);
box(axes1,'on');
hold(axes1,'all');

% Create multiple lines using matrix input to plot
plot(v,probv,'LineWidth',2,'Parent',axes1);
if (verts == 1)
ColOrd = get(gca,'ColorOrder');
% Code here adapted from http://www.mathworks.com/matlabcentral/
% answers/98675-how-can-i-cycle-through-the-colororder-for-my-matlab-figure-when-making-multiple-calls-to-my-plot
[m,~] = size(ColOrd);
%hold on
% Plot the data
for i = 1:numT
    % Determine which row to use in the
    % Color Order Matrix
    ColRow = rem(i,m);
    if ColRow == 0
      ColRow = m;
    end
    % Get the color
    Col = ColOrd(ColRow,:);
    % Plot the data
    for j = 1:3
        plot([vdots(i,j) vdots(i,j)],[0 pdots(i,j)],'o-','Color',Col)
    end
end
end
% Create xlabel
xlabel('Velocity v (m/s)','FontWeight','bold','FontSize',14,...
    'Color',[0 0.5 0]);

% Create ylabel
ylabel('Normalized Probability P(v)','FontWeight','bold','FontSize',14,...
    'Color',[0 0.5 0]);

% Create annotations and legend
text(0.4*maxv,0.98*max(max(probv)),['Particle mass = ',num2str(molwt)],...
    'FontWeight','bold','FontSize',14)
legend(legmat)

% Create title
title('Maxwell-Boltzmann Distribution of Particle Speed',...
    'FontWeight','bold',...
    'FontSize',16);

